@@ -45,7 +45,7 @@ our @EXPORT = qw( process_tos
 		  generate_matrix
 		  );
 our @EXPORT_OK = qw( initialize );
-our $VERSION = '4.4_20';
+our $VERSION = '4.4_21';
 
 my $family;
 
@@ -192,7 +192,7 @@ sub setup_ecn()
 sub add_rule_pair( $$$$ ) {
     my ($chainref , $predicate , $target , $level ) = @_;
 
-    log_rule( $level, $chainref, "\U$target", $predicate )  if defined $level && $level ne '';
+    log_rule( $level, $chainref, "\U$target", $predicate )  if supplied $level;
     add_jump( $chainref , $target, 0, $predicate );
 }
 
@@ -215,7 +215,7 @@ sub setup_blacklist() {
 	$chainref  = dont_delete new_standard_chain 'blacklst' if @$zones;
 	$chainref1 = dont_delete new_standard_chain 'blackout' if @$zones1;
 
-	if ( defined $level && $level ne '' ) {
+	if ( supplied $level ) {
 	    my $logchainref = new_standard_chain 'blacklog';
 
 	    $target =~ s/A_//;
@@ -548,7 +548,8 @@ sub add_common_rules() {
 	    if ( @filters ) {
 		add_jump( $chainref  , $target1, ! $ipsec, match_source_net( $_ ) . $ipsec ), $chainref->{filtered}++ for @filters;
 	    } elsif ( $interfaceref->{bridge} eq $interface ) {
-		add_jump( $chainref , $target1, ! $ipsec, match_dest_dev( $interface ) . $ipsec ), $chainref->{filtered}++ unless $interfaceref->{options}{routeback} || $interfaceref->{options}{routefilter};
+		add_jump( $chainref , $target1, ! $ipsec, match_dest_dev( $interface ) . $ipsec ), $chainref->{filtered}++
+		    unless $interfaceref->{options}{routeback} || $interfaceref->{options}{routefilter} || $interfaceref->{physical} eq '+';
 	    }
 
 	    add_rule( $chainref,  "$globals{STATEMATCH} ESTABLISHED,RELATED -j ACCEPT" ), $chainref->{filtered}++ if $config{FASTACCEPT};
@@ -558,8 +559,6 @@ sub add_common_rules() {
 	
 	    if ( @filters ) {
 		add_jump( $chainref  , $target, 1, match_source_net( $_ ) . $ipsec ), $chainref->{filtered}++ for @filters;
-	    } elsif ( $interfaceref->{bridge} eq $interface ) {
-		add_jump( $chainref , $target, 1, match_dest_dev( $interface ) . $ipsec ), $chainref->{filtered}++ unless $interfaceref->{options}{routeback} || $interfaceref->{options}{routefilter};
 	    }
 	
 	    add_rule( $chainref,  "$globals{STATEMATCH} ESTABLISHED,RELATED -j ACCEPT" ), $chainref->{filtered}++ if $config{FASTACCEPT};
@@ -589,7 +588,7 @@ sub add_common_rules() {
 
 	my $smurfdest = $config{SMURF_DISPOSITION};
 
-	if ( defined $config{SMURF_LOG_LEVEL} && $config{SMURF_LOG_LEVEL} ne '' ) {
+	if ( supplied $config{SMURF_LOG_LEVEL} ) {
 	    my $smurfref = new_chain( 'filter', 'smurflog' );
 
 	    log_rule_limit( $config{SMURF_LOG_LEVEL},
@@ -922,7 +921,7 @@ sub setup_mac_lists( $ ) {
 			for my $address ( split ',', $addresses ) {
 			    my $source = match_source_net $address;
 			    log_rule_limit $level, $chainref , mac_chain( $interface) , $disposition, '', '', 'add' , "${mac}${source}"
-				if defined $level && $level ne '';
+				if supplied $level;
 			    
 			    if ( $audit && $disposition ne 'ACCEPT' ) {
 				if ( $config{FAKE_AUDIT} ) {
@@ -936,7 +935,7 @@ sub setup_mac_lists( $ ) {
 			}
 		    } else {
 			log_rule_limit $level, $chainref , mac_chain( $interface) , $disposition, '', '', 'add' , $mac
-			    if defined $level && $level ne '';
+			    if supplied $level;
 
 			if ( $audit && $disposition ne 'ACCEPT' ) {
 			    if ( $config{FAKE_AUDIT} ) {
@@ -1826,7 +1825,7 @@ sub generate_matrix() {
     }
 
     if ( $config{LOGALLNEW} ) {
-	for my $table qw/mangle nat filter/ {
+	for my $table ( qw/mangle nat filter/ ) {
 	    for my $chain ( @{$builtins{$table}} ) {
 		log_rule_limit
 		    $config{LOGALLNEW} ,
@@ -2153,7 +2152,7 @@ EOF
             #
             # Don't save an 'empty' file
             #
-            grep -q '^-N' ${VARDIR}/ipsets.tmp && mv -f ${VARDIR}/ipsets.tmp ${VARDIR}/ipsets.save
+            grep -qE '^(-N|create )' ${VARDIR}/ipsets.tmp && mv -f ${VARDIR}/ipsets.tmp ${VARDIR}/ipsets.save
         fi
     fi
 EOF
