@@ -3,7 +3,7 @@
 #
 #     This program is under GPL [http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt]
 #
-#     (c) 2007,2008,2009 - Tom Eastep (teastep@shorewall.net)
+#     (c) 2007,2008,2009,2011,2011 - Tom Eastep (teastep@shorewall.net)
 #
 #       Complete documentation is available at http://shorewall.net
 #
@@ -83,7 +83,11 @@ sub setup_one_proxy_arp( $$$$$$$ ) {
 	if ( $family == F_IPV4 ) {
 	    emit "[ -n \"\$g_noroutes\" ] || run_ip route replace $address/32 dev $physical";
 	} else {
-	    emit "[ -n \"\$g_noroutes\" ] || run_ip route replace $address/128 dev $physical";
+	    emit( 'if [ -z "$g_noroutes" ]; then',
+		  "    qt \$IP -6 route del $address/128 dev $physical".
+		  "    run_ip route add $address/128 dev $physical",
+		  'fi'
+		);
 	}
 
 	$haveroute = 1 if $persistent;
